src.nth.io/

summaryrefslogtreecommitdiff
path: root/src/main.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/main.rs')
-rw-r--r--src/main.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/main.rs b/src/main.rs
index f372f8e..d245578 100644
--- a/src/main.rs
+++ b/src/main.rs
@@ -1,4 +1,4 @@
//! mattertimesync: a one-shot CLI Matter controller that sets the clocks of
//! Matter devices via the standard Time Synchronization cluster.
//!
//! # CLI invariants
@@ -54,7 +54,7 @@ use crate::time::MatterMicros;
#[derive(Parser)]
#[command(
- name = "mattertimesync",
+ name = "mattertimectl",
version,
about,
disable_help_subcommand = true
@@ -1,4 +1,4 @@
-//! mattertimesync: a one-shot CLI Matter controller that sets the clocks of
+//! mattertimectl: a one-shot CLI Matter controller that sets the clocks of
//! Matter devices via the standard Time Synchronization cluster.
//!